@@ -65,7 +65,10 @@ LOCAL_STACK = {
 }
 VALID_URLS = {f"http://localhost:{p}" for p in LOCAL_STACK.values()}  # AWS Fargate Task
 VALID_URLS |= {f"http://{h}:{p}" for h, p in LOCAL_STACK.items()}  # local docker-compose stack
-VALID_URLS |= {f"https://{n}-api.materialsproject.org" for n in SUBDOMAINS}
+VALID_URLS |= {
+    f"https://{n}-api{m}.materialsproject.org"
+    for n in SUBDOMAINS for m in ["", "-preview"]
+}
 VALID_URLS |= {f"http://localhost.{n}-api.materialsproject.org" for n in SUBDOMAINS}
 SUPPORTED_FILETYPES = (Gz, Jpeg, Png, Gif, Tiff)
 SUPPORTED_MIMES = [t().mime for t in SUPPORTED_FILETYPES]
@@ -143,6 +146,7 @@ def grouper(n, iterable):
 
 
 def get_session():
+    # TODO add Bad Gateway 502?
     adapter_kwargs = dict(max_retries=Retry(
         total=RETRIES,
         read=RETRIES,
@@ -480,7 +484,7 @@ class Client(SwaggerClient):
                         param_name = f"{column}__{op}"
                         param_spec = deepcopy(param.param_spec)
                         param_spec["name"] = param_name
-                        param_spec.pop("description")
+                        param_spec.pop("description", None)
                         operation.params[param_name] = Param(
                             self.swagger_spec, operation, param_spec
                         )
@@ -1436,6 +1440,7 @@ class Client(SwaggerClient):
                     )
 
                     if not ignore_dupes and dupe:
+                        # TODO add matching duplicate info to msg
                         msg = f"Duplicate in {project_name}: {contrib['identifier']} {dct['name']}"
                         raise ValueError(msg)
 
